package MT::Plugin::MTDefaultTemplatesSimple;

use strict;
use base qw( MT::Plugin );
our $VERSION = '0.2'; 
my $plugin = MT::Plugin::MTDefaultTemplatesSimple->new({
   id          => 'MTDefaultTemplatesSet',
   key         => 'default-template-set',
   name        => 'Default Template Set',
   description => "MT4 Default Template Sets in advanced and simple versions.",
   version     => $VERSION,
   author_name => "Beau Smith",
   author_link => "http://www.beausmith.com",
   plugin_link => "http://plugins.movabletype.org",
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'blog_template_set_change' => \&on_template_set_change,
        },
        template_sets => {
            advanced => {
                label => "Classic Blog - Advanced",
                base_path => 'templates/classic-blog-advanced',
                order => 100,
                templates => {
                    index => {
                        'main_index' => {
                            label => 'Main Index',
                            outfile => 'index.html',
                            rebuild_me => 1,
                        },
                        'archive_index' => {
                            label => 'Archive Index',
                            outfile => 'archives.html',
                            rebuild_me => 1,
                        },
                        'styles' => {
                            label => 'Stylesheet',
                            outfile => 'styles.css',
                            rebuild_me => 1,
                        },
                        'javascript' => {
                            label => 'JavaScript',
                            outfile => 'mt.js',
                        },
                        'rsd' => {
                            label => 'RSD',
                            outfile => 'rsd.xml',
                            rebuild_me => 1,
                        },
                        'atom' => {
                            label => 'Atom',
                            outfile => 'atom.xml',
                            rebuild_me => 1,
                        },
                        'rss' => {
                            label => 'RSS',
                            outfile => 'rss.xml',
                            rebuild_me => 1,
                        },
                    },
                    individual => {
                        'entry' => {
                            label => 'Entry',
                            mappings => {
                                entry_archive => {
                                    archive_type => 'Individual',
                                },
                            },
                        },
                    },
                    page => {
                        'page' => {
                            label => 'Page',
                            mappings => {
                                page_archive => {
                                    archive_type => 'Page',
                                },
                            },
                        },
                    },
                    archive => {
                        'entry_listing' => {
                            label => 'Entry Listing',
                            mappings => {
                                monthly => {
                                    archive_type => 'Monthly',
                                },
                                category_monthly => {
                                    archive_type => 'Category-Monthly',
                                },
                                author_monthly => {
                                    archive_type => 'Author-Monthly',
                                },
                                category => {
                                    archive_type => 'Category',
                                },
                            },
                        },
                    },
                    system => {
                        'comment_response' => {
                            label => 'Comment Response',
                            description_label => 'Displays error, pending or confirmation message for comments.'
                        },
                        'comment_preview' => {
                            label => 'Comment Preview',
                            description_label => 'Displays preview of comment.',
                        },
                        'dynamic_error' => {
                            label => 'Dynamic Error',
                            description_label => 'Displays errors for dynamically published templates.',
                        },
                        'popup_image' => {
                            label => 'Popup Image',
                            description_label => 'Displays image when user clicks a popup-linked image.',
                        },
                        'search_results' => {
                            label => 'Search Results',
                            description_label => 'Displays results of a search.',
                        },
                    },
                    module => {
                        'categories' => {
                            label => 'Categories',
                        },
                        'comment_detail' => {
                            label => 'Comment Detail',
                        },
                        'comment_form' => {
                            label => 'Comment Form',
                        },
                        'comments' => {
                            label => 'Comments',
                        },
                        'entry_detail' => {
                            label => 'Entry Detail',
                        },
                        'entry_summary' => {
                            label => 'Entry Summary',
                        },
                        'entry_metadata' => {
                            label => 'Entry Metadata',
                        },
                        'tags' => {
                            label => 'Tags',
                        },
                        'footer' => {
                            label => 'Footer',
                        },
                        'header' => {
                            label => 'Header',
                        },
                        'sidebar_2col' => {
                            label => 'Sidebar - 2 Column Layout',
                        },
                        'sidebar_3col' => {
                            label => 'Sidebar - 3 Column Layout',
                        },
                        'sidebar' => {
                            label => 'Sidebar',
                        },
                        'trackbacks' => {
                            label => 'TrackBacks',
                        },
                        'page_detail' => {
                            label => 'Page Detail',
                        },
                    },
                },
            },
            simple => {
                label => "Classic Blog - Simple",
                base_path => 'templates/classic-blog-simple',
                order => 100,
                templates => {
                    index => {
                        'main_index' => {
                            label => 'Main Index',
                            outfile => 'index.html',
                            rebuild_me => '1',
                        },
                        'archive_index' => {
                            label => 'Archive Index',
                            outfile => 'archives.html',
                            rebuild_me => '1',
                        },
                        'styles' => {
                            label => 'Stylesheet',
                            outfile => 'styles.css',
                            rebuild_me => '1',
                        },
                        'javascript' => {
                            label => 'JavaScript',
                            outfile => 'mt.js',
                            rebuild_me => '1',
                        },
                        'feed_recent' => {
                            label => 'Atom',
                            outfile => 'atom.xml',
                            rebuild_me => '1',
                        },
                        'rsd' => {
                            label => 'RSD',
                            outfile => 'rsd.xml',
                            rebuild_me => '1',
                        },
                        'rss' => {
                            label => 'RSS',
                            outfile => 'rss.xml',
                            rebuild_me => '1',
                        },
                    },
                    archive => {
                        'entry_listing' => {
                            label => 'Entry Listing',
                            mappings => {
                                monthly => {
                                    archive_type => 'Monthly',
                                },
                                category_monthly => {
                                    archive_type => 'Category-Monthly',
                                },
                                author_monthly => {
                                    archive_type => 'Author-Monthly',
                                },
                                category => {
                                    archive_type => 'Category',
                                },
                            },
                        },
                    },
                    individual => {
                        'entry' => {
                            label => 'Entry',
                            mappings => {
                                entry_archive => {
                                    archive_type => 'Individual',
                                },
                            },
                        },
                        'page' => {
                            label => 'Page',
                            mappings => {
                                page_archive => {
                                    archive_type => 'Page',
                                },
                            },
                        },
                    },
                    module => {
                        'header' => {
                            label => 'Header',
                        },
                        'footer' => {
                            label => 'Footer',
                        },
                        'comments' => {
                            label => 'Comments',
                        },
                        'sidebar' => {
                            label => 'Sidebar',
                        },
                        'trackbacks' => {
                            label => 'Trackbacks',
                        },
                    },
                    system => {
                        'comment_preview' => {
                            label => 'Comment Preview',
                        },
                        'comment_response' => {
                            label => 'Comment Response',
                        },
                        'dynamic_error' => {
                            label => 'Dynamic Error',
                        },
                        'popup_image' => {
                            label => 'Popup Image',
                        },
                        'search_results' => {
                            label => 'Search Results',
                        },
                    },
                },
            },
        },
    });
}

1;